==> haskell-th-orphans-0.13.3-12-i686.pkg.tar.xz: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-orphans
version: 0.13.3
id: th-orphans-0.13.3-AjSyqafunH7F0wdJIUkNrE
key: th-orphans-0.13.3-AjSyqafunH7F0wdJIUkNrE
license: BSD3
copyright: (c) Matt Morrow
maintainer: Michael Sloan <mgsloan at gmail>
stability: experimental
synopsis: Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.
category: Template Haskell
author: Matt Morrow
exposed: True
exposed-modules:
    Language.Haskell.TH.Instances
abi: 667d35c50d4b9562c6dbe055cd0461a2
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/th-orphans-0.13.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/th-orphans-0.13.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/th-orphans-0.13.3
hs-libraries: HSth-orphans-0.13.3-AjSyqafunH7F0wdJIUkNrE
depends:
    base-4.9.1.0 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    template-haskell-2.11.1.0 th-lift-0.7.7-JWI9Gh7wB0MC9Q5wqv5aoI
    th-lift-instances-0.1.11-IT2AhfETPO082BwRxXIbOF
    th-reify-many-0.1.7-8JqqKwBeIMy1cI3ocInzze
haddock-interfaces: /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html: /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-orphans-0.13.3-13-i686.pkg.tar.xz: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-orphans
version: 0.13.3
id: th-orphans-0.13.3-1N7FgGBrfp4F9N2gYS687g
key: th-orphans-0.13.3-1N7FgGBrfp4F9N2gYS687g
license: BSD3
copyright: (c) Matt Morrow
maintainer: Michael Sloan <mgsloan at gmail>
stability: experimental
synopsis: Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.
category: Template Haskell
author: Matt Morrow
exposed: True
exposed-modules:
    Language.Haskell.TH.Instances
abi: f4f9dd994a22c7f069a38e1d2e2fe744
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/th-orphans-0.13.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/th-orphans-0.13.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/th-orphans-0.13.3
hs-libraries: HSth-orphans-0.13.3-1N7FgGBrfp4F9N2gYS687g
depends:
    base-4.9.1.0 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    template-haskell-2.11.1.0 th-lift-0.7.7-JWI9Gh7wB0MC9Q5wqv5aoI
    th-lift-instances-0.1.11-IT2AhfETPO082BwRxXIbOF
    th-reify-many-0.1.7-89nxwFrujGnE4HpHWBm2JG
haddock-interfaces: /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html: /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
